==> jc-1.4.0.tar.gz: soot/options/CPOptions.h <==
// public class soot.options.CPOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c18a848cc1e07064 soot_options_CPOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_CPOptions_H_
#define _JC_soot_options_CPOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_CPOptions$sub_refs	_jc_soot_options_CPOptions$sub_refs;
typedef struct _jc_soot_options_CPOptions$sub_nonrefs	_jc_soot_options_CPOptions$sub_nonrefs;
typedef struct _jc_soot_options_CPOptions$refs	_jc_soot_options_CPOptions$refs;
typedef struct _jc_soot_options_CPOptions$nonrefs	_jc_soot_options_CPOptions$nonrefs;
typedef struct _jc_soot_options_CPOptions$object	_jc_soot_options_CPOptions$object;

typedef const struct _jc_soot_options_CPOptions$vmethods	_jc_soot_options_CPOptions$vmethods;
typedef const struct _jc_soot_options_CPOptions$vtable	_jc_soot_options_CPOptions$vtable;
typedef const struct _jc_soot_options_CPOptions$vtype	_jc_soot_options_CPOptions$vtype;

// Constructors
extern void _jc_soot_options_CPOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_CPOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_CPOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_CPOptions$object *);
extern jboolean _jc_soot_options_CPOptions$method$only__5fregular__5flocals$ab01aafd88ea498c(_jc_env *, struct _jc_soot_options_CPOptions$object *);
extern jboolean _jc_soot_options_CPOptions$method$only__5fstack__5flocals$879d703b37119ff8(_jc_env *, struct _jc_soot_options_CPOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_CPOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_CPOptions$method_info$only__5fregular__5flocals$ab01aafd88ea498c;
extern _jc_method _jc_soot_options_CPOptions$method_info$only__5fstack__5flocals$879d703b37119ff8;

// Virtual methods structure
struct _jc_soot_options_CPOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_CPOptions$object *);
	jboolean	(*only__5fregular__5flocals$ab01aafd88ea498c)(_jc_env *, struct _jc_soot_options_CPOptions$object *);
	jboolean	(*only__5fstack__5flocals$879d703b37119ff8)(_jc_env *, struct _jc_soot_options_CPOptions$object *);
};

// Vtable
struct _jc_soot_options_CPOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_CPOptions$vmethods	soot_options_CPOptions;
};

// Vtype
struct _jc_soot_options_CPOptions$vtype {
	_jc_type			type;
	_jc_soot_options_CPOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_CPOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_CPOptions$refs {
    _jc_soot_options_CPOptions$sub_refs	soot_options_CPOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_CPOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_CPOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_CPOptions$sub_nonrefs	soot_options_CPOptions;
};

// Object instance structure
struct _jc_soot_options_CPOptions$object {
	_jc_soot_options_CPOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_CPOptions$vtype	*vtype;
	_jc_soot_options_CPOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_CPOptions$vtype _jc_soot_options_CPOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_CPOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_CPOptions$class_object;

#endif	/* _JC_soot_options_CPOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/CPOptions.h <==
// public class soot.options.CPOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c18a848cc1e07064 soot_options_CPOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_CPOptions_H_
#define _JC_soot_options_CPOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_CPOptions$sub_refs	_jc_soot_options_CPOptions$sub_refs;
typedef struct _jc_soot_options_CPOptions$sub_nonrefs	_jc_soot_options_CPOptions$sub_nonrefs;
typedef struct _jc_soot_options_CPOptions$refs	_jc_soot_options_CPOptions$refs;
typedef struct _jc_soot_options_CPOptions$nonrefs	_jc_soot_options_CPOptions$nonrefs;
typedef struct _jc_soot_options_CPOptions$object	_jc_soot_options_CPOptions$object;

typedef const struct _jc_soot_options_CPOptions$vmethods	_jc_soot_options_CPOptions$vmethods;
typedef const struct _jc_soot_options_CPOptions$vtable	_jc_soot_options_CPOptions$vtable;
typedef const struct _jc_soot_options_CPOptions$vtype	_jc_soot_options_CPOptions$vtype;

// Constructors
extern void _jc_soot_options_CPOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_CPOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_CPOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_CPOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_CPOptions$method$only__5fregular__5flocals$ab01aafd88ea498c(_jc_env *, struct _jc_soot_options_CPOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_CPOptions$method$only__5fstack__5flocals$879d703b37119ff8(_jc_env *, struct _jc_soot_options_CPOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_CPOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_CPOptions$method_info$only__5fregular__5flocals$ab01aafd88ea498c;
extern _jc_method _jc_soot_options_CPOptions$method_info$only__5fstack__5flocals$879d703b37119ff8;

// Virtual methods structure
struct _jc_soot_options_CPOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_CPOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*only__5fregular__5flocals$ab01aafd88ea498c)(_jc_env *, struct _jc_soot_options_CPOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*only__5fstack__5flocals$879d703b37119ff8)(_jc_env *, struct _jc_soot_options_CPOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_CPOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_CPOptions$vmethods	soot_options_CPOptions;
};

// Vtype
struct _jc_soot_options_CPOptions$vtype {
	_jc_type			type;
	_jc_soot_options_CPOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_CPOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_CPOptions$refs {
    _jc_soot_options_CPOptions$sub_refs	soot_options_CPOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_CPOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_CPOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_CPOptions$sub_nonrefs	soot_options_CPOptions;
};

// Object instance structure
struct _jc_soot_options_CPOptions$object {
	_jc_soot_options_CPOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_CPOptions$vtype	*vtype;
	_jc_soot_options_CPOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_CPOptions$vtype _jc_soot_options_CPOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_CPOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_CPOptions$class_object;

#endif	/* _JC_soot_options_CPOptions_H_ */
